summaryrefslogtreecommitdiffstats
path: root/src/resizeoverlay.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/resizeoverlay.h')
-rw-r--r--src/resizeoverlay.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/resizeoverlay.h b/src/resizeoverlay.h
index aa7a46e..6fbb17f 100644
--- a/src/resizeoverlay.h
+++ b/src/resizeoverlay.h
@@ -119,7 +119,7 @@ class ResizeOverlay : public TQObject
Q_OBJECT
TQ_OBJECT
public:
- ResizeOverlay( Item *tqparent );
+ ResizeOverlay( Item *parent );
~ResizeOverlay();
Item *parentItem() const { return p_item; }
@@ -193,7 +193,7 @@ class MechanicsItemOverlay : public ResizeOverlay
Q_OBJECT
TQ_OBJECT
public:
- MechanicsItemOverlay( MechanicsItem *tqparent );
+ MechanicsItemOverlay( MechanicsItem *parent );
~MechanicsItemOverlay();
public slots:
@@ -229,7 +229,7 @@ public:
void removeBotMiddle();
/**
* Get the size rectangle from the position of the handles. If the size
* is invalid (e.g. the tqparent Item does not consider it a valid size,
* then *ok is set to false; otherwise to true.
* @returns the sizerect, regardless of whether or not it is valid
*/
@@ -263,7 +263,7 @@ class LineOverlay : public ResizeOverlay
Q_OBJECT
TQ_OBJECT
public:
- LineOverlay( Item * tqparent );
+ LineOverlay( Item * parent );
TQPoint startPoint() const;
TQPoint endPoint() const;
@@ -229,7 +229,7 @@ public:
/**
* Get the size rectangle from the position of the handles. If the size
- * is invalid (e.g. the tqparent Item does not consider it a valid size,
+ * is invalid (e.g. the parent Item does not consider it a valid size,
* then *ok is set to false; otherwise to true.
* @returns the sizerect, regardless of whether or not it is valid